==> openshift-model-miscellaneous-5.12.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryStatusBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ImageRegistryStatusBuilder extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryStatusFluentImpl<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryStatus,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryStatusBuilder>{
  public ImageRegistryStatusBuilder() {
    this(false);
  }
  public ImageRegistryStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new ImageRegistryStatus(), validationEnabled);
  }
  public ImageRegistryStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageRegistryStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ImageRegistryStatus(), validationEnabled);
  }
  public ImageRegistryStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryStatusFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryStatus instance) {
    this(fluent, instance, false);
  }
  public ImageRegistryStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryStatusFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withGenerations(instance.getGenerations()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyReplicas(instance.getReadyReplicas()); 
    fluent.withStorage(instance.getStorage()); 
    fluent.withStorageManaged(instance.getStorageManaged()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ImageRegistryStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryStatus instance) {
    this(instance,false);
  }
  public ImageRegistryStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withGenerations(instance.getGenerations()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyReplicas(instance.getReadyReplicas()); 
    this.withStorage(instance.getStorage()); 
    this.withStorageManaged(instance.getStorageManaged()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryStatus build() {
    ImageRegistryStatus buildable = new ImageRegistryStatus(fluent.getConditions(),fluent.getGenerations(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getStorage(),fluent.getStorageManaged(),fluent.getVersion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryStatusBuilder that = (ImageRegistryStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-6.6.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryStatusBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ImageRegistryStatusBuilder extends ImageRegistryStatusFluentImpl<ImageRegistryStatusBuilder> implements VisitableBuilder<ImageRegistryStatus,ImageRegistryStatusBuilder>{
  public ImageRegistryStatusBuilder() {
    this(false);
  }
  public ImageRegistryStatusBuilder(Boolean validationEnabled) {
    this(new ImageRegistryStatus(), validationEnabled);
  }
  public ImageRegistryStatusBuilder(ImageRegistryStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageRegistryStatusBuilder(ImageRegistryStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ImageRegistryStatus(), validationEnabled);
  }
  public ImageRegistryStatusBuilder(ImageRegistryStatusFluent<?> fluent,ImageRegistryStatus instance) {
    this(fluent, instance, false);
  }
  public ImageRegistryStatusBuilder(ImageRegistryStatusFluent<?> fluent,ImageRegistryStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withGenerations(instance.getGenerations()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyReplicas(instance.getReadyReplicas()); 
    fluent.withStorage(instance.getStorage()); 
    fluent.withStorageManaged(instance.getStorageManaged()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ImageRegistryStatusBuilder(ImageRegistryStatus instance) {
    this(instance,false);
  }
  public ImageRegistryStatusBuilder(ImageRegistryStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withGenerations(instance.getGenerations()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyReplicas(instance.getReadyReplicas()); 
    this.withStorage(instance.getStorage()); 
    this.withStorageManaged(instance.getStorageManaged()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ImageRegistryStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ImageRegistryStatus build() {
    ImageRegistryStatus buildable = new ImageRegistryStatus(fluent.getConditions(),fluent.getGenerations(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getStorage(),fluent.getStorageManaged(),fluent.getVersion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
